@@ -72,7 +72,7 @@ int.check.numeric <- function(mat) {
 int.check.rownames <- function(X, lab = "") {
   rnames <- rownames(X)
   rnames <- aue.rmspaces(rnames)
-  if (is.null(rnames) || any(duplicated(rnames))){
+  if (is.null(rnames) || any(duplicated(rnames)) || length(rnames) == 0){
     message("Note: null or duplicated row names. using generic labels.")
     rownames(X) <- aue.genlab(lab, nrow(X))
   }
@@ -91,7 +91,7 @@ int.check.rownames <- function(X, lab = "") {
 int.check.colnames <- function(X, lab = "L") {
   cnames <- colnames(X)
   cnames <- aue.rmspaces(cnames)
-  if (is.null(cnames) || any(duplicated(cnames))){
+  if (is.null(cnames) || any(duplicated(cnames)) || length(cnames) == 0){
     message("Note: null or duplicated column names. using generic labels.")
     colnames(X) <- aue.genlab(lab, ncol(X))
   }
@@ -281,3 +281,39 @@ int.check.group <- function(X, grp = NULL, dummy = TRUE, exp.l = NULL) {
 is.wholenumber <- function(x, tol = .Machine$double.eps^0.5)  abs(x - round(x)) < tol
 
 
+
+
+#---------------------------------------------------
+#' check if elements are numbers and if not convert the matrix using eco.format
+#' @keywords  internal
+
+int.check.to_numeric <- function(x,  to_numeric = FALSE, ...) {
+  
+ncolx <- ncol(x)
+
+if(to_numeric) {
+  x <- eco.format(x, ... )
+  
+} else {
+  
+  # check that the data is in numeric format, using the first <= 20 columns 
+  if(ncolx > 20) {
+    testclass <- unlist(x[, 1:20])
+  } else {
+    testclass <- unlist(x[, seq_len(ncolx)])
+  }
+  
+  if(class(testclass) != "numeric" && class(testclass) != "integer") {
+    stop("Note: recoding of data into numeric format is off (to_numeric = FALSE), 
+                       but the program detected character data in your genetic matrix. 
+                       Try setting: to_numeric = TRUE")
+  }
+  
+}
+
+x
+}
+
+#-----------------------------------------------------------------------------------------#
+
+
